pub struct Link {
pub reference: Option<String>,
pub summary: Option<String>,
pub description: Option<String>,
pub operation_ref: Option<String>,
pub operation_id: Option<String>,
pub parameters: Option<BTreeMap<String, Value>>,
pub request_body: Option<Value>,
pub server: Option<Server>,
}Expand description
Link to an operation that can be followed from a response.
Fields
reference: Option<String>Reference to a link definition.
summary: Option<String>Short summary of the link.
description: Option<String>Description of the link. CommonMark syntax may be used.
operation_ref: Option<String>Relative or absolute URI reference to an operation.
operation_id: Option<String>Name of an existing operation (mutually exclusive with operation_ref).
parameters: Option<BTreeMap<String, Value>>Parameters to pass to the linked operation.
request_body: Option<Value>Request body to use when calling the linked operation.
server: Option<Server>Server to use for the linked operation.