PathItem

Struct PathItem 

pub struct PathItem {
Show 13 fields pub reference: Option<String>, pub summary: Option<String>, pub description: Option<String>, pub get: Option<Operation>, pub put: Option<Operation>, pub post: Option<Operation>, pub delete: Option<Operation>, pub options: Option<Operation>, pub head: Option<Operation>, pub patch: Option<Operation>, pub trace: Option<Operation>, pub servers: Option<Vec<Server>>, pub parameters: Option<Vec<Parameter>>,
}
Describes a single API path and its operations.

A Path Item may contain operation objects for HTTP methods (GET, PUT, POST, etc.), or it may be a reference to another Path Item definition.

Example

use product_os_openapi::{PathItem, Operation};
use std::collections::BTreeMap;

let path_item = PathItem {
    reference: None,
    summary: Some("User operations".to_owned()),
    description: Some("Operations for managing users".to_owned()),
    get: Some(Operation {
        summary: Some("Get user".to_owned()),
        operation_id: Some("getUser".to_owned()),
        tags: Some(vec!["users".to_owned()]),
        description: None,
        external_docs: None,
        parameters: None,
        request_body: None,
        responses: None,
        callbacks: None,
        deprecated: None,
        security: None,
        servers: None,
    }),
    put: None,
    post: None,
    delete: None,
    options: None,
    head: None,
    patch: None,
    trace: None,
    servers: None,
    parameters: None,
};

Fields

reference: Option<String>

Reference to another Path Item. When present, other fields are overridden.

summary: Option<String>

A short summary of the path item.

description: Option<String>

A detailed description of the path item. CommonMark syntax may be used.

get: Option<Operation>

Definition of a GET operation on this path.

put: Option<Operation>

Definition of a PUT operation on this path.

post: Option<Operation>

Definition of a POST operation on this path.

delete: Option<Operation>

Definition of a DELETE operation on this path.

options: Option<Operation>

Definition of an OPTIONS operation on this path.

head: Option<Operation>

Definition of a HEAD operation on this path.

patch: Option<Operation>

Definition of a PATCH operation on this path.

trace: Option<Operation>

Definition of a TRACE operation on this path.

servers: Option<Vec<Server>>

Alternative servers for operations in this path.

parameters: Option<Vec<Parameter>>

Parameters applicable to all operations in this path. Can be overridden at the operation level.