pub struct SchemaProperty {
pub reference: Option<String>,
pub description: Option<String>,
pub all_of: Option<Vec<Box<SchemaProperty>>>,
pub kind: Option<SchemaType>,
pub minimum: Option<u64>,
pub items: Option<Box<Schema>>,
pub min_items: Option<u64>,
pub unique_items: Option<bool>,
pub min_length: Option<u64>,
pub required: Option<Vec<String>>,
}Expand description
Property definition within a Schema.
Similar to Schema but simplified for use as object properties.
Fields
reference: Option<String>Reference to another schema definition.
description: Option<String>Description of the property. CommonMark syntax may be used.
all_of: Option<Vec<Box<SchemaProperty>>>Composition of schemas using allOf.
kind: Option<SchemaType>The data type of the property.
minimum: Option<u64>Minimum value for numeric types.
items: Option<Box<Schema>>Schema for items if this property is an array.
min_items: Option<u64>Minimum number of items if this property is an array.
unique_items: Option<bool>Whether array items must be unique.
min_length: Option<u64>Minimum length for string types.
required: Option<Vec<String>>List of required nested property names.