pub struct ServerVariable {
pub enumeration: Option<Vec<String>>,
pub default: String,
pub description: Option<String>,
}Expand description
Variable substitution information for a Server URL.
Used to provide information about variables that can be substituted in a Server URL template.
Fields
enumeration: Option<Vec<String>>An optional enumeration of allowed values for this variable.
default: StringThe default value for substitution. This field is required.
description: Option<String>An optional description of the variable. CommonMark syntax may be used.